show versions saved for a session
Usage
show_session_versions(
x = get("session", envir = .GlobalEnv),
sessions_path = jamsession_paths()$sessions,
most_recent = FALSE,
return_df = TRUE,
...
)Arguments
- most_recent
logicalwhether to return only the most recently saved entry for each matching session name. If FALSE, it returns all saved versions of all R sessions.- ...
additional arguments are passed to
grep_jamsessions().- session
characterindicating the session name.- session_path
charactervector of one or more file paths to search for saved R sessions.
See also
Other jamsession sessions:
grep_jamsessions(),
load_jamsession(),
save_jamsession()