Clean jamsession name prior to saving an output file
Source:R/jamsession_sessions.R
clean_jamsession_name.RdClean jamsession name prior to saving an output file
Usage
clean_jamsession_name(
x,
remove_pattern = "[-._'\" /\\:]+",
replacement = "_",
verbose = FALSE,
...
)Details
This function is intended to take an R session name as a character
string, and will replace unwanted characters with a fixed string,
by default underscore "_". The remove_pattern and the
replacement are configurable if needed.
See also
Other jamsession internals:
fileInfo(),
list_functions(),
list_jamsessions(),
list_objects(),
print_pkg_description()