Print package DESCRIPTION
Details
This function is a simple wrapper around functions to
find the DESCRIPTION file for an installed R package,
and print lines to the console.
When the package is not installed, or a temporary R package is not in the search path, error messages are returned accordingly.
See also
Other jamsession internals:
clean_jamsession_name(),
fileInfo(),
list_functions(),
list_jamsessions(),
list_objects()
Examples
print_pkg_description("base")
#> Package: base
#> Version: 4.5.1
#> Priority: base
#> Title: The R Base Package
#> Author: R Core Team and contributors worldwide
#> Maintainer: R Core Team <do-use-Contact-address@r-project.org>
#> Contact: R-help mailing list <r-help@r-project.org>
#> Description: Base R functions.
#> License: Part of R 4.5.1
#> Suggests: methods
#> Enhances: chron, date, round
#> Built: R 4.5.1; ; 2025-06-13 07:50:47 UTC; windows